3 ms·
Except Julia vectorised is not as fast as Julia looped. so this : for i = 1:size(a)[1] a[i] = 2a[i] + 3b[i] end is faster than a = 2a .+
by SixSigma 10y ago
Except Julia vectorised is not as fast as Julia looped.
so this :
for i = 1:size(a)[1]
a[i] = 2a[i] + 3b[i]
end
is faster than
a = 2a .+ 3b
(although I haven't benchmarked it)
Here's someone that did : http://aflyax.github.io/de_vectorization-runtime/ http://aflyax.github.io/de_vectorization-runtime/
but in 0.5 there are speedups, apparently.
Here's a stack overflow discussion on it
http://stackoverflow.com/questions/27928502/julia-vectorized-vs-devectorized-code http://stackoverflow.com/questions/27928502/julia-vectorized...
- bauta-steen 10y agoVery interesting, just tested on 0.5 and vectorized can still be a magnitude slower. ulia> @time vect(x, y, a, b) 0.000038 seconds (29 allocations: 37.406 KB) 1×2 Array{Float64,2}: julia> @time devect(x, y, a, b) 0.000006 seconds (10 allocations: 512 bytes) 1×2 Array{Float64,2}: julia> @time vect(x, y, a, b) 0.002324 seconds (73 allocations: 3.075 MB) 416×2 Array{Float64,2}: julia> @time devect(x, y, a, b) 0.000206 seconds (18 allocations: 23.359 KB) 416×2 Array{Float64,2}: